plotto contains a function to display a set of interactive charts created with Altair

## Installing

The latest release can be installed using pip

```bash
pip install plotto
```

see the [Documentation](https://plotto.readthedocs.io/en/latest/) for more details.
